package com.zehong.web.controller.energency;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TSupervisionInspection;
import com.zehong.system.service.ITSupervisionInspectionService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 监督检查记录Controller
 *
 * @author zehong
 * @date 2026-03-16
 */
@RestController
@RequestMapping("/supervision/inspection")
public class TSupervisionInspectionController extends BaseController
{
    @Autowired
    private ITSupervisionInspectionService tSupervisionInspectionService;

    /**
     * 查询监督检查记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TSupervisionInspection tSupervisionInspection)
    {
        startPage();
        List<TSupervisionInspection> list = tSupervisionInspectionService.selectTSupervisionInspectionList(tSupervisionInspection);
        return getDataTable(list);
    }

    /**
     * 导出监督检查记录列表
     */
    @Log(title = "监督检查记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TSupervisionInspection tSupervisionInspection)
    {
        List<TSupervisionInspection> list = tSupervisionInspectionService.selectTSupervisionInspectionList(tSupervisionInspection);
        ExcelUtil<TSupervisionInspection> util = new ExcelUtil<TSupervisionInspection>(TSupervisionInspection.class);
        return util.exportExcel(list, "监督检查记录数据");
    }

    /**
     * 获取监督检查记录详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tSupervisionInspectionService.selectTSupervisionInspectionById(id));
    }

    /**
     * 新增监督检查记录
     */
    @Log(title = "监督检查记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSupervisionInspection tSupervisionInspection)
    {
        return toAjax(tSupervisionInspectionService.insertTSupervisionInspection(tSupervisionInspection));
    }

    /**
     * 修改监督检查记录
     */
    @Log(title = "监督检查记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSupervisionInspection tSupervisionInspection)
    {
        return toAjax(tSupervisionInspectionService.updateTSupervisionInspection(tSupervisionInspection));
    }

    /**
     * 删除监督检查记录
     */
    @Log(title = "监督检查记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSupervisionInspectionService.deleteTSupervisionInspectionByIds(ids));
    }
}